@@ -1,7 +1,7 @@
 from django.contrib.admin.views.decorators import staff_member_required
 from django.urls import path
 
-from .views import ImageUploadView, LinkToolView
+from .views import ImageByUrl, ImageUploadView, LinkToolView
 
 urlpatterns = [
     path(
@@ -14,4 +14,9 @@ urlpatterns = [
         staff_member_required(LinkToolView.as_view()),
         name='editorjs_linktool',
     ),
+    path(
+        'image_by_url/',
+        ImageByUrl.as_view(),
+        name='editorjs_image_by_url',
+    ),
 ]
