@@ -1,3 +1,5 @@
+import urllib.parse
+
 from django.conf import settings
 from django.utils.module_loading import import_string
 
@@ -12,4 +14,9 @@ def get_storage_class():
     )()
 
 
+def get_hostname_from_url(url):
+    obj_url = urllib.parse.urlsplit(url)
+    return obj_url.hostname
+
+
 storage = get_storage_class()
